@@ -58,6 +58,11 @@ file_string = function(file) {
   raw_string(paste(read_utf8(file), collapse = '\n'))
 }
 
+# read all records of a binary file as a raw vector by default
+read_bin = function(file, what = 'raw', n = file.info(file)$size, ...) {
+  readBin(file, what, n, ...)
+}
+
 #' Search and replace strings in files
 #'
 #' These functions provide the "file" version of \code{\link{gsub}()}, i.e.,
@@ -90,7 +95,9 @@ gsub_file = function(file, ..., rw_error = TRUE) {
     (if (rw_error) stop else warning)('Unable to read or write to ', file)
     if (!rw_error) return(invisible())
   }
-  x2 = gsub(x = x1 <- read_utf8(file, error = TRUE), ...)
+  x1 = tryCatch(read_utf8(file, error = TRUE), error = function(e) if (rw_error) stop(e))
+  if (is.null(x1)) return(invisible())
+  x2 = gsub(x = x1, ...)
   if (!identical(x1, x2)) write_utf8(x2, file)
 }
 
